<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.civicuk.com/
 * @since      1.0.0
 *
 * @package    Civic_Cookie_Control_8
 * @subpackage Civic_Cookie_Control_8/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Civic_Cookie_Control_8
 * @subpackage Civic_Cookie_Control_8/admin
 * @author     Civic Uk <info@civicuk.com>
 */
class CCC_Cookie_Control_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function ccc_enqueue_styles() {

		/**
		 * An instance of this class should be passed to the run() function
		 * defined in CCC_Cookie_Control_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The CCC_Cookie_Control_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( 'jquery-ui-css', 'https://code.jquery.com/ui/1.11.2/themes/smoothness/jquery-ui.css' );

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cookie-control-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function ccc_enqueue_scripts() {

		/**
		 * An instance of this class should be passed to the run() function
		 * defined in CCC_Cookie_Control_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The CCC_Cookie_Control_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cookie-control-admin.js', array( 'jquery' ), $this->version, false );

		wp_enqueue_style( 'wp-color-picker' );

		wp_enqueue_script( 'custom-script-handle', plugin_dir_url( __FILE__ ) . 'js/cookie-control-admin-color.js', array( 'wp-color-picker' ), false, true );

		wp_enqueue_script( 'jquery-ui-tabs' );

		wp_enqueue_script( 'jquery-ui-datepicker' );

		wp_enqueue_style( 'jquery-ui' );

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */

	public function ccc_add_plugin_admin_menu() {

		/*
		 * Add a settings page for this plugin to the Settings menu.
		 */
		add_menu_page(
			'Cookie Control 8.',
			'Cookie Control 8',
			'manage_options',
			$this->plugin_name,
			array( $this, 'display_plugin_setup_page' )
		);
	}

	/**
	 * Add settings action link to the plugins page.
	 *
	 * @since    1.0.0
	 */

	public function ccc_add_action_links( $links ) {
		/*
		*  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
		*/

		$settings_link = array(
			'<a href="' . admin_url( 'options-general.php?page=' . $this->plugin_name ) . '">' . __( 'Settings', $this->plugin_name ) . '</a>',
			'<a href="https://www.civicuk.com/cookie-control/downloads/v8/wp/CC8-WP-manual-v1.pdf" target="_blank">' . __( 'Manual' ) . '</a>',
		);
		return array_merge( $settings_link, $links );
	}


	function ccc_get_api_civic( $server_url, $api_key ) {
		$ccc_licenses_type = [ 'CookieControl%20Free', 'CookieControl%20Single-Site', 'CookieControl%20Multi-Site' ];

		foreach ( $ccc_licenses_type as $ccc_license_type ) {
			$ccc_fetchURL = "https://apikeys.civiccomputing.com/c/v?d=$server_url&p=$ccc_license_type&v=8&k=$api_key&format=json";

			$ccc_response = wp_remote_get( $ccc_fetchURL );

			if ( is_wp_error( $ccc_response ) ) {
				$fail_msg = 'not respond';
				return $fail_msg;
			}
			$ccc_body = wp_remote_retrieve_body( $ccc_response );

			$ccc_json_results = json_decode( $ccc_body, true );
			if ( ! isset( $ccc_json_results['valid'] ) ) {
				$fail_msg = 'not respond';
				return $fail_msg;
			} elseif ( $ccc_json_results['valid'] ) {
				return $ccc_json_results;
			}
		}

	}

	/**
	 * Render the settings page for this plugin.
	 *
	 * @since    1.0.0
	 */

	function ccc_cookiecontrol_settings_defaults() {

		// defaults
		$ccc_def_cookiecontrol_logConsent   = 'false';
		$ccc_def_cookiecontrol_initialState = 'CLOSE';
		$ccc_def_cookiecontrol_notifyOnce   = 'false';
		$ccc_def_cookiecontrol_position     = 'RIGHT';
		$ccc_def_cookiecontrol_theme        = 'DARK';
		$ccc_def_cookiecontrol_layout       = 'SLIDEOUT';
		$ccc_def_cookiecontrol_toggleType   = 'slider';
		$ccc_def_cookiecontrol_closeStyle   = 'icon';
		$ccc_def_cookiecontrol_expiry       = 90;

		$ccc_def_cookiecontrol_fontColor        = '#fff';
		$ccc_def_cookiecontrol_fontFamily       = 'Arial,sans-serif';
		$ccc_def_cookiecontrol_fontSizeTitle    = '1.2';
		$ccc_def_cookiecontrol_fontSizeHeaders  = '1';
		$ccc_def_cookiecontrol_fontSize         = '0.8';
		$ccc_def_cookiecontrol_backgroundColor  = '#313147';
		$ccc_def_cookiecontrol_toggleText       = '#fff';
		$ccc_def_cookiecontrol_toggleColor      = '#2f2f5f';
		$ccc_def_cookiecontrol_toggleBackground = '#111125';
		$ccc_def_cookiecontrol_buttonIcon       = null;
		$ccc_def_cookiecontrol_buttonIconWidth  = '64';
		$ccc_def_cookiecontrol_buttonIconHeight = '64';
		$ccc_def_cookiecontrol_removeIcon       = 'false';
		$ccc_def_cookiecontrol_removeAbout      = 'false';
		$ccc_def_cookiecontrol_alertText        = '#fff';
		$ccc_def_cookiecontrol_alertBackground  = '#111125';
		$ccc_def_cookiecontrol_acceptTextColor  = '#ffffff';
		$ccc_def_cookiecontrol_acceptBackground = '#111125';

		$ccc_def_cookiecontrol_titleText             = 'This site uses cookies';
		$ccc_def_cookiecontrol_introText             = 'Some of these cookies are essential, while others help us to improve your experience by providing insights into how the site is being used.';
		$ccc_def_cookiecontrol_privacyURL            = '';
		$ccc_def_cookiecontrol_privacyName           = '';
		$ccc_def_cookiecontrol_privacyDescription    = '';
		$ccc_def_cookiecontrol_privacyUpdateDate     = '';
		$ccc_def_cookiecontrol_necessaryTitle        = 'Necessary Cookies';
		$ccc_def_cookiecontrol_necessaryDescription  = 'Necessary cookies enable core functionality. The website cannot function properly without these cookies, and can only be disabled by changing your browser preferences.';
		$ccc_def_cookiecontrol_thirdPartyTitle       = 'Warning: Some cookies require your attention';
		$ccc_def_cookiecontrol_thirdPartyDescription = 'Consent for the following cookies could not be automatically revoked. Please follow the link(s) below to opt out manually.';
		$ccc_def_cookiecontrol_offText               = 'Off';
		$ccc_def_cookiecontrol_onText                = 'On';
		$ccc_def_cookiecontrol_acceptText            = 'Accept';
		$ccc_def_cookiecontrol_settingsText          = 'Cookie Preferences';
		$ccc_def_cookiecontrol_notifyTitle           = 'Your choice regarding cookies on this site';
		$ccc_def_cookiecontrol_notifyDescription     = 'We use cookies to optimise site functionality and give you the best possible experience.';
		$ccc_def_cookiecontrol_acceptRecommended     = 'Accept Recommended Settings';
		$ccc_def_cookiecontrol_closeLabel            = 'Close';
		$ccc_def_cookiecontrol_accessibilityAlert    = 'This site uses cookies to store information. Press accesskey C to learn more about your options.';

		$ccc_def_cookiecontrol_accessKey      = 'C';
		$ccc_def_cookiecontrol_highlightFocus = 'false';

		// define defaults
		$ccc_cookiecontrol_defaults = apply_filters(
			'cookiecontrol_defaults',
			array(
				'logConsent'            => $ccc_def_cookiecontrol_logConsent,
				'notifyOnce'            => $ccc_def_cookiecontrol_notifyOnce,
				'initialState'          => $ccc_def_cookiecontrol_initialState,
				'position'              => $ccc_def_cookiecontrol_position,
				'theme'                 => $ccc_def_cookiecontrol_theme,
				'layout'                => $ccc_def_cookiecontrol_layout,
				'toggleType'            => $ccc_def_cookiecontrol_toggleType,
				'closeStyle'            => $ccc_def_cookiecontrol_closeStyle,
				'expiry'                => $ccc_def_cookiecontrol_expiry,

				'fontColor'             => $ccc_def_cookiecontrol_fontColor,
				'fontFamily'            => $ccc_def_cookiecontrol_fontFamily,
				'fontSizeTitle'         => $ccc_def_cookiecontrol_fontSizeTitle,
				'fontSizeHeaders'       => $ccc_def_cookiecontrol_fontSizeHeaders,
				'fontSize'              => $ccc_def_cookiecontrol_fontSize,
				'backgroundColor'       => $ccc_def_cookiecontrol_backgroundColor,
				'toggleText'            => $ccc_def_cookiecontrol_toggleText,
				'toggleColor'           => $ccc_def_cookiecontrol_toggleColor,
				'toggleBackground'      => $ccc_def_cookiecontrol_toggleBackground,
				'buttonIcon'            => $ccc_def_cookiecontrol_buttonIcon,
				'buttonIconWidth'       => $ccc_def_cookiecontrol_buttonIconWidth,
				'buttonIconHeight'      => $ccc_def_cookiecontrol_buttonIconHeight,
				'removeIcon'            => $ccc_def_cookiecontrol_removeIcon,
				'removeAbout'           => $ccc_def_cookiecontrol_removeAbout,
				'alertText'             => $ccc_def_cookiecontrol_alertText,
				'alertBackground'       => $ccc_def_cookiecontrol_alertBackground,
				'acceptTextColor'       => $ccc_def_cookiecontrol_acceptTextColor,
				'acceptBackground'      => $ccc_def_cookiecontrol_acceptBackground,

				'titleText'             => $ccc_def_cookiecontrol_titleText,
				'introText'             => $ccc_def_cookiecontrol_introText,
				'privacyURL'            => $ccc_def_cookiecontrol_privacyURL,
				'necessaryTitle'        => $ccc_def_cookiecontrol_necessaryTitle,
				'necessaryDescription'  => $ccc_def_cookiecontrol_necessaryDescription,
				'thirdPartyTitle'       => $ccc_def_cookiecontrol_thirdPartyTitle,
				'thirdPartyDescription' => $ccc_def_cookiecontrol_thirdPartyDescription,
				'onText'                => $ccc_def_cookiecontrol_onText,
				'offText'               => $ccc_def_cookiecontrol_offText,
				'acceptText'            => $ccc_def_cookiecontrol_acceptText,
				'settingsText'          => $ccc_def_cookiecontrol_settingsText,
				'acceptRecommended'     => $ccc_def_cookiecontrol_acceptRecommended,
				'notifyTitle'           => $ccc_def_cookiecontrol_notifyTitle,
				'notifyDescription'     => $ccc_def_cookiecontrol_notifyDescription,
				'closeLabel'            => $ccc_def_cookiecontrol_closeLabel,
				'accessibilityAlert'    => $ccc_def_cookiecontrol_accessibilityAlert,

				'accessKey'             => $ccc_def_cookiecontrol_accessKey,
				'highlightFocus'        => $ccc_def_cookiecontrol_highlightFocus,
			)
		);
		return $ccc_cookiecontrol_defaults;
	}

	function ccc_cookiecontrol_settings_init() {
		$ccc_cookiecontrol_settings = wp_parse_args( get_option( 'civic_cookiecontrol_settings' ), $this->ccc_cookiecontrol_settings_defaults() );
		return $ccc_cookiecontrol_settings;
	}

	public function display_plugin_setup_page() {
		include_once 'partials/cookie-control-admin-display.php';
	}

	function ccc_cookiecontrol_settings_validate() {

		if(isset($_POST['civic_cookiecontrol_settings'])){
			$input = $_POST['civic_cookiecontrol_settings'];
		}elseif(isset($_POST['cookiecontrol_settings'])){
			$input = $_POST['cookiecontrol_settings'];
		}

		$allowedHTML = array(
			'a'      => array(
				'href'  => array(),
				'title' => array(),
			),
			'br'     => array(),
			'em'     => array(),
			'strong' => array(),
			'p'      => array(),
			'ul'     => array(),
			'ol'     => array(),
			'li'     => array(),
		);

		$input['logConsent']   = wp_filter_nohtml_kses( $input['logConsent'] );
		$input['notifyOnce']   = wp_filter_nohtml_kses( $input['notifyOnce'] );
		$input['position']     = wp_filter_nohtml_kses( $input['position'] );
		$input['theme']        = wp_filter_nohtml_kses( $input['theme'] );
		$input['layout']       = wp_filter_nohtml_kses( $input['layout'] );
		$input['initialState'] = wp_filter_nohtml_kses( $input['initialState'] );
		$input['toggleType']   = wp_filter_nohtml_kses( $input['toggleType'] );
		$input['closeStyle']   = wp_filter_nohtml_kses( $input['closeStyle'] );
		$input['expiry']       = ( empty( $input['expiry'] ) || ! is_numeric( $input['expiry'] ) ) ? '' : $input['expiry'];

		$input['titleText']             = sanitize_text_field( wp_filter_nohtml_kses( $input['titleText'] ) );
		$input['introText']             = wp_kses( $input['introText'], $allowedHTML );
		$input['necessaryTitle']        = sanitize_text_field( wp_filter_nohtml_kses( $input['necessaryTitle'] ) );
		$input['necessaryDescription']  = wp_kses( $input['necessaryDescription'], $allowedHTML );
		$input['thirdPartyTitle']       = sanitize_text_field( wp_filter_nohtml_kses( $input['thirdPartyTitle'] ) );
		$input['thirdPartyDescription'] = wp_kses( $input['thirdPartyDescription'], $allowedHTML );
		$input['onText']                = sanitize_text_field( wp_filter_nohtml_kses( $input['onText'] ) );
		$input['offText']               = sanitize_text_field( wp_filter_nohtml_kses( $input['offText'] ) );
		$input['acceptText']            = sanitize_text_field( wp_filter_nohtml_kses( $input['acceptText'] ) );
		$input['settingsText']          = sanitize_text_field( wp_filter_nohtml_kses( $input['settingsText'] ) );
		$input['privacyURL']            = sanitize_text_field( $input['privacyURL'] );
		if ( isset( $input['privacyName'] ) ) {
			$input['privacyName'] = sanitize_text_field( wp_filter_nohtml_kses( $input['privacyName'] ) );
		}
		if ( isset( $input['privacyDescription'] ) ) {
			$input['privacyDescription'] = sanitize_text_field( wp_filter_nohtml_kses( $input['privacyDescription'] ) );
		}
		if ( isset( $input['privacyUpdateDate'] ) ) {
			$input['privacyUpdateDate'] = sanitize_text_field( $input['privacyUpdateDate'] );
		}
		$input['acceptRecommended'] = sanitize_text_field( wp_filter_nohtml_kses( $input['acceptRecommended'] ) );
		$input['notifyTitle']       = sanitize_text_field( wp_filter_nohtml_kses( $input['notifyTitle'] ) );
		$input['notifyDescription'] = wp_kses( $input['notifyDescription'], $allowedHTML );

		$input['closeLabel']         = sanitize_text_field( wp_filter_nohtml_kses( $input['closeLabel'] ) );
		$input['accessibilityAlert'] = sanitize_text_field( wp_filter_nohtml_kses( $input['accessibilityAlert'] ) );

		$input['fontColor']        = ( empty( $input['fontColor'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['fontColor'] ) ) ? '' : $input['fontColor'];
		$input['fontSizeTitle']    = ( empty( $input['fontSizeTitle'] ) || ! is_numeric( $input['fontSizeTitle'] ) ) ? '' : $input['fontSizeTitle'];
		$input['fontSizeHeaders']  = ( empty( $input['fontSizeHeaders'] ) || ! is_numeric( $input['fontSizeHeaders'] ) ) ? '' : $input['fontSizeHeaders'];
		$input['fontSize']         = ( empty( $input['fontSize'] ) || ! is_numeric( $input['fontSize'] ) ) ? '' : $input['fontSize'];
		$input['backgroundColor']  = ( empty( $input['backgroundColor'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['backgroundColor'] ) ) ? '' : $input['backgroundColor'];
		$input['toggleText']       = ( empty( $input['toggleText'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['toggleText'] ) ) ? '' : $input['toggleText'];
		$input['toggleColor']      = ( empty( $input['toggleColor'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['toggleColor'] ) ) ? '' : $input['toggleColor'];
		$input['toggleBackground'] = ( empty( $input['toggleBackground'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['toggleBackground'] ) ) ? '' : $input['toggleBackground'];
		$input['buttonIcon']       = ( empty( $input['buttonIcon'] ) ) ? null : esc_url( $input['buttonIcon'] );
		$input['buttonIconWidth']  = ( empty( $input['buttonIconWidth'] ) || ! is_numeric( $input['buttonIconWidth'] ) ) ? '64' : $input['buttonIconWidth'];
		$input['buttonIconHeight'] = ( empty( $input['buttonIconHeight'] ) || ! is_numeric( $input['buttonIconHeight'] ) ) ? '64' : $input['buttonIconHeight'];
		$input['alertText']        = ( empty( $input['alertText'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['alertText'] ) ) ? '' : $input['alertText'];
		$input['alertBackground']  = ( empty( $input['alertBackground'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['alertBackground'] ) ) ? '' : $input['alertBackground'];
		$input['acceptTextColor']  = ( empty( $input['acceptTextColor'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['acceptTextColor'] ) ) ? '' : $input['acceptTextColor'];
		$input['acceptBackground'] = ( empty( $input['acceptBackground'] ) || ! preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $input['acceptBackground'] ) ) ? '' : $input['acceptBackground'];

		if ( ! empty( $input['optionalCookiesName'] ) && is_array( $input['optionalCookiesName'] ) ) {
			foreach ( $input['optionalCookiesName'] as $key => $val ) :
				$input['optionalCookiesName'][ $key ]                  = str_replace( ' ', '_', sanitize_text_field( $input['optionalCookiesName'][ $key ] ) );
				$input['optionalCookiesLabel'][ $key ]                 = esc_js( wp_strip_all_tags( $input['optionalCookiesLabel'][ $key ] ) );
				$input['optionalCookiesDescription'][ $key ]           = esc_js( wp_strip_all_tags( $input['optionalCookiesDescription'][ $key ] ) );
				$input['optionalCookiesArray'][ $key ]                 = stripslashes( sanitize_textarea_field( $input['optionalCookiesArray'][ $key ] ) );
				$input['optionalCookiesthirdPartyCookiesName'][ $key ] = sanitize_text_field( $input['optionalCookiesthirdPartyCookiesName'][ $key ] );
				$input['optionalCookiesthirdPartyCookiesUrl'][ $key ]  = sanitize_text_field( $input['optionalCookiesthirdPartyCookiesUrl'][ $key ] );
				if ( isset( $input[ 'optionalCookiesthirdPartyCookiesName' . $key ] ) ) {
					foreach ( $input[ 'optionalCookiesthirdPartyCookiesName' . $key ] as $key2 => $val2 ) {
						$input[ 'optionalCookiesthirdPartyCookiesName' . $key . '' ][ $key2 ] = sanitize_text_field( $input[ 'optionalCookiesthirdPartyCookiesName' . $key . '' ][ $key2 ] );
						$input[ 'optionalCookiesthirdPartyCookiesUrl' . $key . '' ][ $key2 ]  = sanitize_text_field( $input[ 'optionalCookiesthirdPartyCookiesUrl' . $key . '' ][ $key2 ] );
					}
				}
			endforeach;
		}

		if ( ! empty( $input['necessaryCookies'] ) && is_array( $input['necessaryCookies'] ) ) {
			foreach ( $input['necessaryCookies'] as $key => $val ) :
				$input['necessaryCookies'][ $key ] = esc_js( sanitize_text_field( $val ) );
			endforeach;
		}
		// add by default wp session cookies
		if ( ! empty( $input['excludedCountries'] ) && is_array( $input['excludedCountries'] ) ) {
			foreach ( $input['excludedCountries'] as $key => $val ) :
				$input['excludedCountries'][ $key ] = esc_js( sanitize_text_field( $val ) );
			endforeach;
		}

		if ( ! empty( $input['altLanguages'] ) && is_array( $input['altLanguages'] ) ) {
			foreach ( $input['altLanguages'] as $key => $val ) :
				$input['altLanguages'][ $key ]     = esc_js( sanitize_text_field( $val ) );
				$input['altLanguagesText'][ $key ] = wp_kses( $input['altLanguagesText'][ $key ], $allowedHTML );
			endforeach;
		}

		return $input;
	}

	function ccc_cookiecontrol_settings_update_check() {
		$ccc_cookiecontrol_settings = $this->ccc_cookiecontrol_settings_init();

		if ( isset( $ccc_cookiecontrol_settings['update'] ) ) {
			echo '<div class="updated fade" id="message"><p>Cookie Control Settings <strong>' . $ccc_cookiecontrol_settings['update'] . '</strong></p></div>';
			unset( $ccc_cookiecontrol_settings['update'] );
		}

	}

	function ccc_cookiecontrol_args() {

		if(get_option( $this->plugin_name )){

			$ccc_cookiecontrol_settings = get_option( $this->plugin_name );

		}elseif(get_option( 'cookiecontrol_settings' )){

			$ccc_cookiecontrol_settings = get_option( 'cookiecontrol_settings' );

		}

		$ccc_cookiecontrol_productval = get_option( 'civic_cookiecontrol_productval' );

		$allowedHTML = array(
			'a'      => array(
				'href'  => array(),
				'title' => array(),
			),
			'br'     => array(),
			'em'     => array(),
			'strong' => array(),
			'p'      => array(),
			'ul'     => array(),
			'ol'     => array(),
			'li'     => array(),
		);

		if ( isset( $ccc_cookiecontrol_settings['apiKey'] ) && $ccc_cookiecontrol_settings['apiKey'] != '' ) :
			$ccc_output_extra_cookies       = '';
			$ccc_output_extra_cookies_array = [];
			$ccc_product_val                = '';
			if ( ! empty( $ccc_cookiecontrol_settings['optionalCookiesName'] ) ) {

				foreach ( $ccc_cookiecontrol_settings['optionalCookiesName'] as $key => $val ) {
					if ( ( isset( $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesName'][ $key ] ) && $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesName'][ $key ] ) && ( isset( $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesUrl'][ $key ] ) && $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesUrl'][ $key ] ) ) {
						$ccc_output_extra_cookies .= '{"name": "' . $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesName'][ $key ] . '",  "optOutLink" : "' . $ccc_cookiecontrol_settings['optionalCookiesthirdPartyCookiesUrl'][ $key ] . '"}';
						if ( isset( $ccc_cookiecontrol_settings[ 'optionalCookiesthirdPartyCookiesName' . $key ] ) ) {

							foreach ( $ccc_cookiecontrol_settings[ 'optionalCookiesthirdPartyCookiesName' . $key ] as $key2 => $val2 ) {

								$ccc_output_extra_cookies .= ' , {"name": "' . $ccc_cookiecontrol_settings[ 'optionalCookiesthirdPartyCookiesName' . $key ][ $key2 ] . '", "optOutLink" : "' . $ccc_cookiecontrol_settings[ 'optionalCookiesthirdPartyCookiesUrl' . $key ][ $key2 ] . '"}';
							}
						}
					}
					$ccc_output_extra_cookies_array[] = $ccc_output_extra_cookies;
					$ccc_output_extra_cookies         = '';
				}
			}

			if ( isset( $ccc_cookiecontrol_productval ) && $ccc_cookiecontrol_productval != '' ) {
				$ccc_product_val = $ccc_cookiecontrol_productval;
			} elseif ( isset( $ccc_cookiecontrol_settings['product'] ) ) {
				$ccc_product_val = $ccc_cookiecontrol_settings['product'];
			}
			?>

			<script type="text/javascript">
				var config = {
					apiKey: '<?php echo esc_html( $ccc_cookiecontrol_settings['apiKey'] ); ?>',
					product: '<?php echo esc_html( $ccc_product_val ); ?>',
					logConsent: <?php echo esc_html( $ccc_cookiecontrol_settings['logConsent'] ); ?>,
					notifyOnce: <?php echo esc_html( $ccc_cookiecontrol_settings['notifyOnce'] ); ?>,
					initialState: '<?php echo esc_html( $ccc_cookiecontrol_settings['initialState'] ); ?>',
					position: '<?php echo esc_html( $ccc_cookiecontrol_settings['position'] ); ?>',
					theme: '<?php echo esc_html( $ccc_cookiecontrol_settings['theme'] ); ?>',
					layout: '<?php echo esc_html( $ccc_cookiecontrol_settings['layout'] ); ?>',
					toggleType: '<?php echo esc_html( $ccc_cookiecontrol_settings['toggleType'] ); ?>',
					closeStyle: '<?php echo esc_html( $ccc_cookiecontrol_settings['closeStyle'] ); ?>',
					consentCookieExpiry: <?php echo !empty( $ccc_cookiecontrol_settings['expiry'] ) ? esc_html( $ccc_cookiecontrol_settings['expiry'] ) : '0'; ?>,

					accessibility: {
						accessKey: '<?php echo esc_html( $ccc_cookiecontrol_settings['accessKey'] ); ?>',
						highlightFocus: <?php echo esc_html( $ccc_cookiecontrol_settings['highlightFocus'] ); ?>,
					},

					text: {
						title: '<?php echo esc_html( $ccc_cookiecontrol_settings['titleText'] ); ?>',
						intro: '<?php echo wp_kses( preg_replace( "/\r\n|\r|\n/", '<br/>', $ccc_cookiecontrol_settings['introText'] ), $allowedHTML ); ?>',
						necessaryTitle: '<?php echo esc_html( $ccc_cookiecontrol_settings['necessaryTitle'] ); ?>',
						necessaryDescription: '<?php echo wp_kses( preg_replace( "/\r\n|\r|\n/", '<br/>', $ccc_cookiecontrol_settings['necessaryDescription'] ), $allowedHTML ); ?>',
						thirdPartyTitle: '<?php echo esc_html( $ccc_cookiecontrol_settings['thirdPartyTitle'] ); ?>',
						thirdPartyDescription: '<?php preg_replace( "/\r\n|\r|\n/", '<br/>', $ccc_cookiecontrol_settings['thirdPartyDescription'] ); ?>',
						on: '<?php echo esc_html( $ccc_cookiecontrol_settings['onText'] ); ?>',
						off: '<?php echo esc_html( $ccc_cookiecontrol_settings['offText'] ); ?>',
						accept: '<?php echo esc_html( $ccc_cookiecontrol_settings['acceptText'] ); ?>',
						settings: '<?php echo esc_html( $ccc_cookiecontrol_settings['settingsText'] ); ?>',
						acceptRecommended: '<?php echo esc_html( $ccc_cookiecontrol_settings['acceptRecommended'] ); ?>',
						notifyTitle: '<?php echo esc_html( $ccc_cookiecontrol_settings['notifyTitle'] ); ?>',
						notifyDescription: '<?php echo wp_kses( preg_replace( "/\r\n|\r|\n/", '<br/>', $ccc_cookiecontrol_settings['notifyDescription'] ), $allowedHTML ); ?>',
						closeLabel: '<?php echo esc_html( $ccc_cookiecontrol_settings['closeLabel'] ); ?>',
						accessibilityAlert: '<?php echo esc_html( $ccc_cookiecontrol_settings['accessibilityAlert'] ); ?>',
					},

					<?php if ( $ccc_product_val != 'COMMUNITY' ) : ?>

					branding: {
						fontColor: '<?php echo esc_html( $ccc_cookiecontrol_settings['fontColor'] ); ?>',
						fontFamily: '<?php echo esc_html( $ccc_cookiecontrol_settings['fontFamily'] ); ?>',
						fontSizeTitle: '<?php echo esc_html( $ccc_cookiecontrol_settings['fontSizeTitle'] ); ?>em',
						fontSizeHeaders: '<?php echo esc_html( $ccc_cookiecontrol_settings['fontSizeHeaders'] ); ?>em',
						fontSize: '<?php echo esc_html( $ccc_cookiecontrol_settings['fontSize'] ); ?>em',
						backgroundColor: '<?php echo esc_html( $ccc_cookiecontrol_settings['backgroundColor'] ); ?>',
						toggleText: '<?php echo esc_html( $ccc_cookiecontrol_settings['toggleText'] ); ?>',
						toggleColor: '<?php echo esc_html( $ccc_cookiecontrol_settings['toggleColor'] ); ?>',
						toggleBackground: '<?php echo esc_html( $ccc_cookiecontrol_settings['toggleBackground'] ); ?>',
						alertText: '<?php echo esc_html( $ccc_cookiecontrol_settings['alertText'] ); ?>',
						alertBackground: '<?php echo esc_html( $ccc_cookiecontrol_settings['alertBackground'] ); ?>',
						acceptText: '<?php echo esc_html( $ccc_cookiecontrol_settings['acceptTextColor'] ); ?>',
						acceptBackground: '<?php echo esc_html( $ccc_cookiecontrol_settings['acceptBackground'] ); ?>',
						<?php if ( empty( $ccc_cookiecontrol_settings['buttonIcon'] ) ) : ?>
						buttonIcon: null,
						<?php else : ?>
						buttonIcon: '<?php echo esc_url( $ccc_cookiecontrol_settings['buttonIcon'] ); ?>',
						<?php endif; ?>
						buttonIconWidth: '<?php echo esc_html( $ccc_cookiecontrol_settings['buttonIconWidth'] ); ?>px',
						buttonIconHeight: '<?php echo esc_html( $ccc_cookiecontrol_settings['buttonIconHeight'] ); ?>px',
						removeIcon: <?php echo esc_html( $ccc_cookiecontrol_settings['removeIcon'] ); ?>,
						removeAbout: <?php echo esc_html( $ccc_cookiecontrol_settings['removeAbout'] ); ?>
					},
					<?php endif; ?>
					<?php if ( isset( $ccc_cookiecontrol_settings['excludedCountries'] ) && is_array( $ccc_cookiecontrol_settings['excludedCountries'] ) && count( $ccc_cookiecontrol_settings['excludedCountries'] ) > 0 && ! empty( $ccc_cookiecontrol_settings['excludedCountries'] ) ) : ?>
						<?php
						$excludedCountriesVal = '';
						foreach ( $ccc_cookiecontrol_settings['excludedCountries'] as $key => $val ) :
							$excludedCountriesVal .= $val != '' ? "'" . $val . "'," : '';
					endforeach;
						?>
						<?php if ( $ccc_product_val != 'COMMUNITY' ) : ?>
							<?php if ( $excludedCountriesVal != '' ) : ?>
					excludedCountries: [ <?php echo wp_kses( substr( $excludedCountriesVal, 0, -1 ), $allowedHTML ); ?> ],
					<?php endif; ?>
					<?php endif; ?>
					<?php endif; ?>
					<?php if ( $ccc_product_val != 'COMMUNITY' ) : ?>
						<?php
						if ( isset( $ccc_cookiecontrol_settings['altLanguages'] ) ) :
							if ( is_array( $ccc_cookiecontrol_settings['altLanguages'] ) && count( $ccc_cookiecontrol_settings['altLanguages'] ) > 0 && ! empty( $ccc_cookiecontrol_settings['altLanguages'] ) ) :
								?>
					locales: [
								<?php foreach ( $ccc_cookiecontrol_settings['altLanguages'] as $key => $val ) : ?>
									<?php if ( $val != '' && $ccc_cookiecontrol_settings['altLanguagesText'][ $key ] != '' ) : ?>
						{
							locale: '<?php echo esc_html( $val ); ?>',
										<?php echo wp_kses( stripslashes( $ccc_cookiecontrol_settings['altLanguagesText'][ $key ] ), $allowedHTML ); ?>
						},
						<?php endif; ?>
						<?php endforeach; ?>
					],
								<?php
						endif;
					endif;
						?>
					<?php endif; ?>
					<?php
					$necessaryCookiesVal = "'wordpress_*','wordpress_logged_in_*','CookieControl',";
					?>
					<?php if ( isset( $ccc_cookiecontrol_settings['necessaryCookies'] ) && is_array( $ccc_cookiecontrol_settings['necessaryCookies'] ) && count( $ccc_cookiecontrol_settings['necessaryCookies'] ) > 0 && ! empty( $ccc_cookiecontrol_settings['necessaryCookies'] ) ) : ?>
						<?php
						foreach ( $ccc_cookiecontrol_settings['necessaryCookies'] as $key => $val ) :
							$necessaryCookiesVal .= $val != '' ? "'" . $val . "'," : '';
					endforeach;
						?>
					<?php endif; ?>

					<?php if ( $necessaryCookiesVal != '' ) : ?>
					necessaryCookies: [ <?php echo wp_kses( substr( $necessaryCookiesVal, 0, -1 ), $allowedHTML ); ?> ],
					<?php endif; ?>

					<?php if ( isset( $ccc_cookiecontrol_settings['optionalCookiesName'] ) && is_array( $ccc_cookiecontrol_settings['optionalCookiesName'] ) && count( $ccc_cookiecontrol_settings['optionalCookiesName'] ) > 0 && ! empty( $ccc_cookiecontrol_settings['optionalCookiesName'] ) ) : ?>
					optionalCookies: [
						<?php foreach ( $ccc_cookiecontrol_settings['optionalCookiesName'] as $key => $val ) : ?>
							<?php if ( $val != '' ) : ?>
						{
							name: '<?php echo esc_html( $val ); ?>',
							label: '<?php echo esc_html( $ccc_cookiecontrol_settings['optionalCookiesLabel'][ $key ] ); ?>',
							description: '<?php echo esc_html( $ccc_cookiecontrol_settings['optionalCookiesDescription'][ $key ] ); ?>',
							cookies: [ <?php echo wp_kses( stripslashes( $ccc_cookiecontrol_settings['optionalCookiesArray'][ $key ] ), $allowedHTML ); ?> ],
							onAccept: function () {
								<?php echo wp_kses( stripslashes( $ccc_cookiecontrol_settings['optionalCookiesonAccept'][ $key ] ), $allowedHTML ); ?>
							},
							onRevoke: function () {
								<?php echo wp_kses( stripslashes( $ccc_cookiecontrol_settings['optionalCookiesonRevoke'][ $key ] ), $allowedHTML ); ?>
							},
								<?php if ( ! empty( $ccc_output_extra_cookies_array[ $key - 1 ] ) ) : ?>
							thirdPartyCookies: [<?php echo wp_kses( stripslashes( $ccc_output_extra_cookies_array[ $key - 1 ] ), $allowedHTML ); ?>],
							<?php endif; ?>
							recommendedState: '<?php echo esc_html( $ccc_cookiecontrol_settings['optionalCookiesinitialConsentState'][ $key ] ); ?>',
							lawfulBasis: '<?php echo isset( $ccc_cookiecontrol_settings['optionalCookieslawfulBasis'] ) ? esc_html( $ccc_cookiecontrol_settings['optionalCookieslawfulBasis'][ $key ] ) : 'consent'; ?>',
						},
						<?php endif; ?>
						<?php endforeach; ?>
					],
					<?php endif; ?>

					<?php if ( isset( $ccc_cookiecontrol_settings['privacyURL'] ) && ! empty( $ccc_cookiecontrol_settings['privacyURL'] ) ) : ?>
					statement: {
						description: '<?php echo wp_kses( stripslashes( $ccc_cookiecontrol_settings['privacyDescription'] ), $allowedHTML ); ?>',
						name: '<?php echo esc_html( $ccc_cookiecontrol_settings['privacyName'] ); ?>',
						url: '<?php echo esc_url( $ccc_cookiecontrol_settings['privacyURL'] ); ?>',
						updated: '<?php echo esc_html( $ccc_cookiecontrol_settings['privacyUpdateDate'] ); ?>'
					},
					<?php endif; ?>
				};
				CookieControl.load(config);
			</script>

			<?php
		endif;
	}


	public function ccc_options_update() {

		register_setting( 'civic_cookiecontrol_settings', 'civic_cookiecontrol_settings', array( $this, 'ccc_cookiecontrol_settings_validate' ) );

	}

}